@@ -31,6 +31,7 @@
 #include <QString>
 
 DWIDGET_USE_NAMESPACE
+DCORE_USE_NAMESPACE
 
 class Utils : public QObject
 {
@@ -54,6 +55,10 @@ public:
     static bool is3rdInterfaceStart;
     static bool isTabletEnvironment;
     static bool isWaylandMode;
+    /**
+     * @brief 本机是否存在ffmpeg相关库 true:存在 false:不存在
+     */
+    static bool isFFmpegEnv;
     static bool isRootUser;
     static int themeType;
     /**
@@ -106,6 +111,12 @@ public:
 
     static void getAllWindowInfo(const quint32 winId, const int width, const int height, QList<QRect> &windowRects, QList<QString> &windowNames);
     static bool checkCpuIsZhaoxin();
+
+    /**
+     * @brief 获取处理器名称
+     * @return 处理器名称
+     */
+    static QString getCpuModelName();
 };
 
 #endif //UTILS_H
