@@ -33,6 +33,7 @@
 
 #include <com_deepin_daemon_audio.h>
 #include <com_deepin_daemon_audio_sink.h>
+#include <com_deepin_daemon_audio_source.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -208,21 +209,21 @@ QString AudioUtils::currentAudioChannel()
     QScopedPointer<com::deepin::daemon::audio::Sink> defaultSink;
 
     audioInterface.reset(
-                new com::deepin::daemon::Audio(
-                    serviceName,
-                    "/com/deepin/daemon/Audio",
-                    QDBusConnection::sessionBus(),
-                    this )
-                );
+        new com::deepin::daemon::Audio(
+            serviceName,
+            "/com/deepin/daemon/Audio",
+            QDBusConnection::sessionBus(),
+            this)
+    );
 
     defaultSink.reset(
-                new com::deepin::daemon::audio::Sink (
-                    serviceName,
-                    audioInterface->defaultSink().path(),
-                    QDBusConnection::sessionBus(),
-                    this)
-                );
-    if (defaultSink->isValid()){
+        new com::deepin::daemon::audio::Sink(
+            serviceName,
+            audioInterface->defaultSink().path(),
+            QDBusConnection::sessionBus(),
+            this)
+    );
+    if (defaultSink->isValid()) {
         QString sinkName = defaultSink->name();
         QStringList options;
         options << "-c";
@@ -238,3 +239,60 @@ QString AudioUtils::currentAudioChannel()
     }
     return "";
 }
+
+QString AudioUtils::getDefaultDeviceName(DefaultAudioType mode)
+{
+    QString device = "";
+    const QString serviceName {"com.deepin.daemon.Audio"};
+
+    QScopedPointer<com::deepin::daemon::Audio> audioInterface;
+    audioInterface.reset(
+        new com::deepin::daemon::Audio(
+            serviceName,
+            "/com/deepin/daemon/Audio",
+            QDBusConnection::sessionBus(),
+            this)
+    );
+    if (mode == DefaultAudioType::Sink) {
+        QScopedPointer<com::deepin::daemon::audio::Sink> defaultSink;
+        defaultSink.reset(
+            new com::deepin::daemon::audio::Sink(
+                serviceName,
+                audioInterface->defaultSink().path(),
+                QDBusConnection::sessionBus(),
+                this)
+        );
+        if (defaultSink->isValid()) {
+            qInfo() << "default sink name is : " << defaultSink->name();
+            qInfo() << "default sink activePort name : " << defaultSink->activePort().name;
+            qInfo() << "             activePort description : " << defaultSink->activePort().description;
+            qInfo() << "             activePort availability : " << defaultSink->activePort().availability;
+            device = defaultSink->name();
+            if (!device.isEmpty() && !device.endsWith(".monitor")) {
+                device += ".monitor";
+            }
+        }
+    } else if (mode == DefaultAudioType::Source) {
+        QScopedPointer<com::deepin::daemon::audio::Source> defaultSource;
+        defaultSource.reset(
+            new com::deepin::daemon::audio::Source(
+                serviceName,
+                audioInterface->defaultSource().path(),
+                QDBusConnection::sessionBus(),
+                this)
+        );
+        if (defaultSource->isValid()) {
+            qInfo() << "default source name is : " << defaultSource->name();
+            qInfo() << "default source activePort name : " << defaultSource->activePort().name;
+            qInfo() << "               activePort description : " << defaultSource->activePort().description;
+            qInfo() << "               activePort availability : " << defaultSource->activePort().availability;
+            device = defaultSource->name();
+            if (device.endsWith(".monitor")) {
+                device.clear();
+            }
+        }
+    } else {
+        qCritical() << "The passed parameter is incorrect! Please pass in 1 or 2!";
+    }
+    return device;
+}
