@@ -22,8 +22,6 @@
 #ifndef SCREENGRABBER_H
 #define SCREENGRABBER_H
 
-#include "../utils/desktopinfo.h"
-
 #include <QObject>
 
 class ScreenGrabber : public QObject
@@ -32,9 +30,6 @@ class ScreenGrabber : public QObject
 public:
     explicit ScreenGrabber(QObject *parent = nullptr);
     QPixmap grabEntireDesktop(bool &ok, const QRect &rect, const qreal devicePixelRatio);
-
-private:
-    DesktopInfo m_info;
 };
 
 #endif // SCREENGRABBER_H
