@@ -398,7 +398,7 @@ int CAVOutputStream::init_context_amix(int channel, uint64_t channel_layout, int
         return false;
     }
 
-    pCodecCtx_amix = avlibInterface::m_avcodec_alloc_context3(pCodec_amix);
+    //pCodecCtx_amix = avlibInterface::m_avcodec_alloc_context3(pCodec_amix); //注释此行无效代码，同时解决内存泄露
     pCodecCtx_amix = avlibInterface::m_avcodec_alloc_context3(pCodec_a);
     pCodecCtx_amix->channels = m_channels;
     pCodecCtx_amix->channel_layout = static_cast<uint64_t>(m_channels_layout);
@@ -681,6 +681,7 @@ int CAVOutputStream::writeVideoFrame(WaylandIntegration::WaylandIntegrationPriva
     if (nullptr == frame._frame || frame._width <= 0 || frame._height <= 0) {
         return -1;
     }
+    //qint64 time1 = QDateTime::currentMSecsSinceEpoch();
     AVFrame *pRgbFrame = avlibInterface::m_av_frame_alloc();
     pRgbFrame->width = frame._width;
     pRgbFrame->height = frame._height;
@@ -697,8 +698,12 @@ int CAVOutputStream::writeVideoFrame(WaylandIntegration::WaylandIntegrationPriva
         pRgbFrame->data[0]     = frame._frame;
     }
     if (nullptr == m_pVideoSwsContext) {
+        AVPixelFormat fmt = AV_PIX_FMT_RGBA;
+        if (m_boardVendorType) {
+            fmt = AV_PIX_FMT_RGB32;
+        }
         m_pVideoSwsContext = avlibInterface::m_sws_getContext(m_width, m_height,
-                                                              AV_PIX_FMT_RGBA,
+                                                              fmt,
                                                               pCodecCtx->width,
                                                               pCodecCtx->height,
                                                               AV_PIX_FMT_YUV420P,
@@ -711,7 +716,10 @@ int CAVOutputStream::writeVideoFrame(WaylandIntegration::WaylandIntegrationPriva
         AVERROR(ERANGE);
         return 2;
     }
+    //qint64 time2 = QDateTime::currentMSecsSinceEpoch();
     avlibInterface::m_sws_scale(m_pVideoSwsContext, pRgbFrame->data, pRgbFrame->linesize, 0, pCodecCtx->height, pFrameYUV->data, pFrameYUV->linesize);
+    //qint64 time3 = QDateTime::currentMSecsSinceEpoch();
+    //qDebug() << "time3 - time2: sws_scale : " << time3-time2;
     pFrameYUV->width  = pRgbFrame->width;//test
     pFrameYUV->height = pRgbFrame->height;
     pFrameYUV->format = AV_PIX_FMT_YUV420P;
@@ -730,7 +738,8 @@ int CAVOutputStream::writeVideoFrame(WaylandIntegration::WaylandIntegrationPriva
             m_fristVideoFramePts = frame._time;
         }
         packet.pts = static_cast<int64_t>(m_videoStream->time_base.den) * (frame._time - m_fristVideoFramePts) / AV_TIME_BASE;
-        //qDebug() << "video packet.pts: " << packet.pts;        packet.dts =  packet.pts;
+        //qDebug() << "video packet.pts: " << packet.pts << " , " << static_cast<int64_t>(m_videoStream->time_base.den) << " * " << frame._time - m_fristVideoFramePts << " / " << AV_TIME_BASE;
+        packet.dts =  packet.pts;
         int ret = writeFrame(m_videoFormatContext, &packet);
         if (ret < 0) {
             //char tmpErrString[128] = {0};
@@ -739,6 +748,8 @@ int CAVOutputStream::writeVideoFrame(WaylandIntegration::WaylandIntegrationPriva
             return ret;
         }
     }
+    //qint64 time4 = QDateTime::currentMSecsSinceEpoch();
+    //qDebug() << "time4 - time1: writeVideoFrame : " << time4-time1;
     avlibInterface::m_av_free_packet(&packet);
     avlibInterface::m_av_frame_free(&pRgbFrame);
     fflush(stdout);
@@ -789,6 +800,7 @@ int CAVOutputStream::writeMicAudioFrame(AVStream *stream, AVFrame *inputFrame, i
         printf("Could not allocate converted input samples\n");
         avlibInterface::m_av_freep(&(*m_convertedMicSamples)[0]);
         free(*m_convertedMicSamples);
+        freeSwrContext(m_pMicAudioSwrContext);
         return ret;
     }
 
@@ -800,8 +812,10 @@ int CAVOutputStream::writeMicAudioFrame(AVStream *stream, AVFrame *inputFrame, i
     //extended_data -> m_convertedMicSamples
     if ((ret = avlibInterface::m_swr_convert(m_pMicAudioSwrContext, m_convertedMicSamples, inputFrame->nb_samples, const_cast<const uint8_t **>(inputFrame->extended_data), inputFrame->nb_samples)) < 0) {
         printf("Could not convert input samples\n");
+        freeSwrContext(m_pMicAudioSwrContext);
         return ret;
     }
+    freeSwrContext(m_pMicAudioSwrContext);
     AVRational rational;
     int audioSize = audioFifoSize(m_micAudioFifo);
     //因为Fifo里有之前未读完的数据，所以从Fifo队列里面取出的第一个音频包的时间戳等于当前时间减掉缓冲部分的时长
@@ -901,7 +915,13 @@ int CAVOutputStream::writeMicAudioFrame(AVStream *stream, AVFrame *inputFrame, i
             outputPacket.stream_index = m_micAudioStream->index;
             printf("output_packet.stream_index1  audio_st =%d\n", outputPacket.stream_index);
             //outputPacket.pts = avlibInterface::m_av_rescale_q(m_nLastAudioPresentationTime, rational, m_micAudioStream->time_base);
-            outputPacket.pts = m_singleCount * m_pMicCodecContext->frame_size * 1000 / m_pMicCodecContext->sample_rate;
+            if (m_videoType == videoType::MKV) {
+                //显示时间戳，应大于或等于解码时间戳
+                outputPacket.pts = m_singleCount * m_pMicCodecContext->frame_size * 1000 / m_pMicCodecContext->sample_rate;
+            } else {
+                //显示时间戳，应大于或等于解码时间戳
+                outputPacket.pts = m_singleCount * m_pMicCodecContext->frame_size;
+            }
             outputPacket.dts = outputPacket.pts;
             //qDebug() << m_singleCount << " mic audio outputPacket.pts: " << outputPacket.pts;
             m_singleCount++;
@@ -947,12 +967,15 @@ int CAVOutputStream::writeMicToMixAudioFrame(AVStream *stream, AVFrame *inputFra
         printf("Could not allocate converted input samples\n");
         avlibInterface::m_av_freep(&(*m_convertedMicSamples)[0]);
         free(*m_convertedMicSamples);
+        freeSwrContext(m_pMicAudioSwrContext);
         return ret;
     }
     if ((ret = avlibInterface::m_swr_convert(m_pMicAudioSwrContext, m_convertedMicSamples, inputFrame->nb_samples, const_cast<const uint8_t **>(inputFrame->extended_data), inputFrame->nb_samples)) < 0) {
         printf("Could not convert input samples\n");
+        freeSwrContext(m_pMicAudioSwrContext);
         return ret;
     }
+    freeSwrContext(m_pMicAudioSwrContext);
     int fifoSpace = audioFifoSpace(m_micAudioFifo);
     if (fifoSpace < inputFrame->nb_samples) {
         fifoSpace = avlibInterface::m_av_audio_fifo_size(m_micAudioFifo);
@@ -1047,6 +1070,21 @@ int CAVOutputStream::write_filter_audio_frame(AVStream *&outst, AVCodecContext *
     //     av_frame_free(&output_frame);
     return ret;
 }
+/**
+ * @brief 音频缓冲区是否还有数据
+ * @return
+ */
+bool CAVOutputStream::isNotAudioFifoEmty()
+{
+    bool flag  = false;
+    if ((m_micAudioFifo != nullptr && audioFifoSize(m_micAudioFifo) >= m_pMicCodecContext->frame_size) ||
+            (m_sysAudioFifo != nullptr && audioFifoSize(m_sysAudioFifo) >= m_pSysCodecContext->frame_size)) {
+        flag = true;
+    }
+    //qDebug () << "isNotAudioFifoEmty() : " << flag << audioFifoSize(m_sysAudioFifo) << audioFifoSpace(m_sysAudioFifo) << " , " << audioFifoSize(m_micAudioFifo) << audioFifoSpace(m_micAudioFifo);
+
+    return flag;
+}
 
 void CAVOutputStream::writeMixAudio()
 {
@@ -1104,7 +1142,7 @@ void CAVOutputStream::writeMixAudio()
             printf("Mixer: failed to call av_buffersrc_add_frame (microphone)\n");
             return;
         }
-        while (isWriteFrame()) {
+        while (isWriteFrame() || isNotAudioFifoEmty()) {
             //两种音频混合后输出的帧
             AVFrame *pFrame_out = avlibInterface::m_av_frame_alloc();
             //AVERROR(EAGAIN) 返回这个表示还没转换完成既 不存在帧，则返回AVERROR（EAGAIN）
@@ -1131,6 +1169,7 @@ void CAVOutputStream::writeMixAudio()
                 }
                 if (got_packet_ptr) {
                     packet_out.stream_index = audio_amix_st->index;
+
                     if (m_videoType == videoType::MKV) {
                         //显示时间戳，应大于或等于解码时间戳
                         packet_out.pts = m_mixCount * pCodecCtx_amix->frame_size * 1000 / pFrame_out->sample_rate;
@@ -1138,7 +1177,7 @@ void CAVOutputStream::writeMixAudio()
                         //显示时间戳，应大于或等于解码时间戳
                         packet_out.pts = m_mixCount * pCodecCtx_amix->frame_size;
                     }
-                    //qDebug() << m_mixCount << " mix audio packet_out.pts: " << packet_out.pts;
+                    qDebug() << m_mixCount << " mix audio packet_out.pts: " << packet_out.pts ;
 
                     packet_out.dts = packet_out.pts;
                     packet_out.duration = pCodecCtx_amix->frame_size;
@@ -1204,9 +1243,9 @@ int  CAVOutputStream::writeSysAudioFrame(AVStream *stream, AVFrame *inputFrame,
                 m_sysAudioFifo = audioFifoAlloc(m_pSysCodecContext->sample_fmt, m_pSysCodecContext->channels,  40 * inputFrame->nb_samples);
             }
             //qDebug() << "init m_sysAudioFifo audioFifoSize: " << audioFifoSize(m_sysAudioFifo);
-            //qDebug() << "init m_sysAudioFifo audioFifoSpace: " << audioFifoSpace(m_sysAudioFifo);        }
-            is_fifo_scardinit ++;
+            //qDebug() << "init m_sysAudioFifo audioFifoSpace: " << audioFifoSpace(m_sysAudioFifo);
         }
+        is_fifo_scardinit ++;
     }
     /**
     * Allocate memory for the samples of all channels in one consecutive
@@ -1216,6 +1255,7 @@ int  CAVOutputStream::writeSysAudioFrame(AVStream *stream, AVFrame *inputFrame,
     if ((ret = avlibInterface::m_av_samples_alloc(m_convertedSysSamples, nullptr, m_pSysCodecContext->channels, inputFrame->nb_samples, m_pSysCodecContext->sample_fmt, 0)) < 0) {
         avlibInterface::m_av_freep(&(*m_convertedSysSamples)[0]);
         free(*m_convertedSysSamples);
+        freeSwrContext(m_pSysAudioSwrContext);
         return ret;
     }
 
@@ -1225,8 +1265,10 @@ int  CAVOutputStream::writeSysAudioFrame(AVStream *stream, AVFrame *inputFrame,
     */
     /** Convert the samples using the resampler. */
     if ((ret = avlibInterface::m_swr_convert(m_pSysAudioSwrContext, m_convertedSysSamples, inputFrame->nb_samples, const_cast<const uint8_t **>(inputFrame->extended_data), inputFrame->nb_samples)) < 0) {
+        freeSwrContext(m_pSysAudioSwrContext);
         return ret;
     }
+    freeSwrContext(m_pSysAudioSwrContext);
     AVRational rational = {1, AV_TIME_BASE };
     int audioSize = audioFifoSize(m_sysAudioFifo);
     int64_t timeshift = (int64_t)audioSize * AV_TIME_BASE / (int64_t)(stream->codec->sample_rate);
@@ -1235,6 +1277,7 @@ int  CAVOutputStream::writeSysAudioFrame(AVStream *stream, AVFrame *inputFrame,
     * Make the FIFO as large as it needs to be to hold both,
     * the old and the new samples.使FIFO尽可能大，因为它需要容纳旧的和新的样品。
     */
+    //qDebug() << "m_videoType: " << m_videoType;
     if (m_videoType == videoType::MKV) {
         //对比某个时间段缓冲区大小是否比初始化缓冲区大小大，大：需要减小当前的缓冲区，小不做操作
         if (m_initFifoSpace < audioFifoSpace(m_sysAudioFifo)) {
@@ -1330,13 +1373,19 @@ int  CAVOutputStream::writeSysAudioFrame(AVStream *stream, AVFrame *inputFrame,
         /** Write one audio frame from the temporary packet to the output file. */
         if (enc_got_frame_a) {
             outputPacket.stream_index = m_sysAudioStream->index;
-            outputPacket.pts = m_singleCount * m_pSysCodecContext->frame_size * 1000 / m_pSysCodecContext->sample_rate;
-            if (m_videoType == videoType::MP4) {
+//            outputPacket.pts = m_singleCount * m_pSysCodecContext->frame_size * 1000 / m_pSysCodecContext->sample_rate;
+            if (m_videoType == videoType::MKV) {
+                //显示时间戳，应大于或等于解码时间戳
+                outputPacket.pts = m_singleCount * m_pSysCodecContext->frame_size * 1000 / m_pSysCodecContext->sample_rate;
+            } else {
+                //显示时间戳，应大于或等于解码时间戳
+                outputPacket.pts = m_singleCount * m_pSysCodecContext->frame_size;
                 outputPacket.dts = outputPacket.pts;
             }
             outputPacket.duration = m_pSysCodecContext->frame_size;
             //qDebug() << m_singleCount << " sys audio outputPacket.pts: " << outputPacket.pts;
-            m_singleCount++;                if ((ret = writeFrame(m_videoFormatContext, &outputPacket)) < 0) {
+            m_singleCount++;
+            if ((ret = writeFrame(m_videoFormatContext, &outputPacket)) < 0) {
                 //char tmpErrString[128] = {0};
                 //printf("Could not write audio frame, error: %s\n", av_make_error_string(tmpErrString, AV_ERROR_MAX_STRING_SIZE, ret));
                 avlibInterface::m_av_packet_unref(&outputPacket);
@@ -1378,6 +1427,7 @@ int CAVOutputStream::writeSysToMixAudioFrame(AVStream *stream, AVFrame *inputFra
     if ((ret = avlibInterface::m_av_samples_alloc(m_convertedSysSamples, nullptr, m_pSysCodecContext->channels, inputFrame->nb_samples, m_pSysCodecContext->sample_fmt, 0)) < 0) {
         avlibInterface::m_av_freep(&(*m_convertedSysSamples)[0]);
         free(*m_convertedSysSamples);
+        freeSwrContext(m_pSysAudioSwrContext);
         return ret;
     }
     /*
@@ -1387,9 +1437,12 @@ int CAVOutputStream::writeSysToMixAudioFrame(AVStream *stream, AVFrame *inputFra
      * 可以通过使用swr_get_out_samples()检索给定输入样本数量所需输出样本数量的上限来避免这种缓冲。只要有可能，转换将直接运行而不进行复制。
      */
     if ((ret = avlibInterface::m_swr_convert(m_pSysAudioSwrContext, m_convertedSysSamples, inputFrame->nb_samples, const_cast<const uint8_t **>(inputFrame->extended_data), inputFrame->nb_samples)) < 0) {
+        freeSwrContext(m_pSysAudioSwrContext);
         return ret;
     }
 
+    freeSwrContext(m_pSysAudioSwrContext);
+
     int fifoSpace = audioFifoSpace(m_sysAudioFifo);
     if (fifoSpace < inputFrame->nb_samples) {
         fifoSpace = avlibInterface::m_av_audio_fifo_size(m_sysAudioFifo);
@@ -1516,7 +1569,7 @@ int CAVOutputStream::writeTrailer(AVFormatContext *s)
 }
 
 /**
- * @brief 获取当前af中可供读取的样本数
+ * @brief 获取当前af中可供写入的样本数（剩余空间）
  * @param af
  * @return
  */
@@ -1527,6 +1580,11 @@ int CAVOutputStream::audioFifoSpace(AVAudioFifo *af)
     return avlibInterface::m_av_audio_fifo_space(af);
 }
 
+/**
+ * @brief 获取当前af中可供读取的样本数（已使用空间）
+ * @param af
+ * @return
+ */
 int CAVOutputStream::audioFifoSize(AVAudioFifo *af)
 {
     //qDebug() << "+++++++++++++++++++++++ 2";
@@ -1558,6 +1616,9 @@ void CAVOutputStream::audioFifoFree(AVAudioFifo *af)
 bool CAVOutputStream::isWriteFrame()
 {
     QMutexLocker locker(&m_isWriteFrameMutex);
+    if (isNotAudioFifoEmty()) {
+        return true;
+    }
     return m_isWriteFrame;
 }
 
@@ -1567,3 +1628,18 @@ void CAVOutputStream::setIsWriteFrame(bool isWriteFrame)
     m_isWriteFrame = isWriteFrame;
 }
 
+void CAVOutputStream::setBoardVendor(int boardVendorType)
+{
+    m_boardVendorType = boardVendorType;
+}
+
+//释放swrContext
+void CAVOutputStream::freeSwrContext(SwrContext *swrContext)
+{
+    Q_UNUSED(swrContext);
+//    if (swrContext != nullptr) {
+//        avlibInterface::m_swr_free(&swrContext);
+//        swrContext = nullptr;
+//    }
+}
+
