@@ -28,6 +28,7 @@
 #include <QHBoxLayout>
 #include <QDir>
 #include <QBitmap>
+#include <QtConcurrent>
 
 
 CameraWidget::CameraWidget(DWidget *parent) : DWidget(parent)
@@ -117,7 +118,12 @@ void CameraWidget::initCamera()
 
 bool CameraWidget::cameraStart()
 {
-    camera->start();
+    if (m_isInitCamera) {
+        timer_image_capture->start(50);
+        return true;
+    }else {
+        camera->start();
+    }
 
     if (imageCapture->isCaptureDestinationSupported(QCameraImageCapture::CaptureToFile)) {
         imageCapture->setCaptureDestination(QCameraImageCapture::CaptureToFile);
@@ -155,20 +161,21 @@ bool CameraWidget::cameraStart()
         imageCapture->setEncodingSettings(iamge_setting);
         connect(imageCapture, &QCameraImageCapture::imageCaptured, this, &CameraWidget::processCapturedImage);
         connect(imageCapture, &QCameraImageCapture::imageSaved, this, &CameraWidget::deleteCapturedImage);
-        timer_image_capture->start(50);
+        timer_image_capture->start(200);
+        m_isInitCamera = true;
         return true;
     }
 
-    else {
-        return false;
-    }
+
+    return false;
 }
 
 void CameraWidget::cameraStop()
 {
     timer_image_capture->stop();
-    camera->stop();
-    m_cameraUI->clear();
+    //camera->stop();
+    //camera->unload();
+    //m_cameraUI->clear();
 }
 
 void CameraWidget::cameraResume()
@@ -180,6 +187,8 @@ void CameraWidget::cameraResume()
 //    camera->load();
     camera->setCaptureMode(QCamera::CaptureStillImage);
     imageCapture = new QCameraImageCapture(camera, this);
+
+    m_isInitCamera = false;
 }
 /*
  * never used
@@ -190,7 +199,7 @@ bool CameraWidget::getScreenResolution()
 */
 void CameraWidget::captureImage()
 {
-    imageCapture->capture(m_capturePath);
+   imageCapture->capture(m_capturePath);
 }
 
 void CameraWidget::processCapturedImage(int request_id, const QImage &img)
