@@ -104,8 +104,8 @@ void SubToolWidget::initRecordLabel()
     } else if (t_saveGifVar.toString() == "false") {
         t_saveGif = false;
     } else {
-        t_settings->setValue("recordConfig", "save_as_gif", true);
-        t_saveGif = true;
+        t_settings->setValue("recordConfig", "save_as_gif", false);
+        t_saveGif = false;
     }
 
     if (t_saveMkvVar.toString() == "true") {
@@ -385,10 +385,22 @@ void SubToolWidget::initRecordLabel()
     formatTitleAction->setText(tr("Format:"));
     gifAction->setText(tr("GIF"));
     gifAction->setCheckable(true);
-    mp4Action->setText(tr("MP4"));
+    if (Utils::isFFmpegEnv) {
+        mp4Action->setText(tr("MP4"));
+    } else {
+        mp4Action->setText(tr("webm"));
+        //Gstreamer录屏时，不存在gif，避免此开关被打开
+        t_saveGif = false;
+    }
     mp4Action->setCheckable(true);
-    mkvAction->setText(tr("MKV"));
+
+    if (Utils::isFFmpegEnv) {
+        mkvAction->setText(tr("MKV"));
+    } else {
+        mkvAction->setText(tr("ogg"));
+    }
     mkvAction->setCheckable(true);
+
     t_formatGroup->addAction(gifAction);
     t_formatGroup->addAction(mp4Action);
     t_formatGroup->addAction(mkvAction);
@@ -414,11 +426,14 @@ void SubToolWidget::initRecordLabel()
 
     m_recordOptionMenu->addAction(formatTitleAction);
 #if !(defined (__mips__) || defined (__sw_64__) || defined (__loongarch_64__))
-    m_recordOptionMenu->addAction(gifAction);
+    if (Utils::isFFmpegEnv) {
+        m_recordOptionMenu->addAction(gifAction);
+    }
 #endif
     m_recordOptionMenu->addAction(mp4Action);
-
-    m_recordOptionMenu->addAction(mkvAction);
+    if (Utils::isFFmpegEnv) {
+        m_recordOptionMenu->addAction(mkvAction);
+    }
     m_recordOptionMenu->addSeparator();
 
     m_recordOptionMenu->addAction(fpsTitleAction);
@@ -634,7 +649,7 @@ void SubToolWidget::initShotLabel()
     Utils::setAccessibility(m_pinButton, AC_SUBTOOLWIDGET_PINSCREENSHOTS_BUTTON);
     m_shotBtnGroup->addButton(m_pinButton);
     m_pinButton->setFixedSize(MIN_TOOL_BUTTON_SIZE);
-    installTipHint(m_pinButton, tr("Pin screenshots"));
+    installTipHint(m_pinButton, tr("Pin Screenshots"));
     btnList.append(m_pinButton);
 
     //添加滚动截图按钮
@@ -645,8 +660,9 @@ void SubToolWidget::initShotLabel()
     m_shotBtnGroup->addButton(m_scrollShotButton);
     m_scrollShotButton->setFixedSize(MIN_TOOL_BUTTON_SIZE);
     installTipHint(m_scrollShotButton, tr("Scrollshot"));
+#ifdef  OCR_SCROLL_FLAGE_ON
     btnList.append(m_scrollShotButton);
-
+#endif
     //添加ocr图文识别按钮
     m_ocrButton = new ToolButton();
     m_ocrButton->setIconSize(QSize(35, 35));
@@ -655,7 +671,9 @@ void SubToolWidget::initShotLabel()
     m_shotBtnGroup->addButton(m_ocrButton);
     m_ocrButton->setFixedSize(MIN_TOOL_BUTTON_SIZE);
     installTipHint(m_ocrButton, tr("Extract Text"));
+#ifdef  OCR_SCROLL_FLAGE_ON
     btnList.append(m_ocrButton);
+#endif
 
     ToolButton *seperator2 = new ToolButton(this);
     if (Utils::themeType != 1) {
@@ -762,6 +780,7 @@ void SubToolWidget::initShotLabel()
         m_shotOptionButton->hide();
         m_scrollShotButton->hide(); //隐藏滚动截图按钮
         m_ocrButton->hide(); //隐藏ocr按钮
+        m_pinButton->hide(); //隐藏pin按钮
     }
     btnList.append(m_shotOptionButton);
 
@@ -1108,6 +1127,20 @@ void SubToolWidget::setPinScreenshotsEnable(const bool &state)
     m_pinButton->setEnabled(state);
 }
 
+void SubToolWidget::setOcrScreenshotEnable(const bool &state)
+{
+    m_ocrButton->setEnabled(state);
+}
+
+void SubToolWidget::setButEnableOnLockScreen(const bool &state)
+{
+    m_textButton->setEnabled(state);
+    m_optionButton->setEnabled(state);
+    m_shotOptionButton->setEnabled(state);
+    m_audioButton->setEnabled(state);
+    m_mouseButton->setEnabled(state);
+}
+
 void SubToolWidget::switchContent(QString shapeType)
 {
     if (shapeType == "record") {
@@ -1224,7 +1257,7 @@ void SubToolWidget::shapeClickedFromWidget(QString shape)
         } else if (shape == "text") {
             m_textButton->click();
         } else if (shape == "option") {
-            if (m_optionMenu->isHidden() && !Utils::isTabletEnvironment) {
+            if (m_shotOptionButton->isEnabled() && m_optionMenu->isHidden() && !Utils::isTabletEnvironment) {
                 m_shotOptionButton->showMenu();
 //                QPoint point = QWidget::mapToGlobal(m_shotOptionButton->pos());
 //                m_optionMenu->move(point.x(),point.y()+m_shotOptionButton->size().height());
@@ -1234,7 +1267,7 @@ void SubToolWidget::shapeClickedFromWidget(QString shape)
                 m_optionMenu->hide();
             }
         } else if (QString("record_option") == shape) {
-            if (m_recordOptionMenu->isHidden() && !Utils::isTabletEnvironment) {
+            if (m_optionButton->isEnabled() && m_recordOptionMenu->isHidden() && !Utils::isTabletEnvironment) {
                 m_optionButton->showMenu();
 //                QPoint point = QWidget::mapToGlobal(m_optionButton->pos());
 //                m_recordOptionMenu->move(point.x(),point.y()+m_optionButton->size().height());
@@ -1246,7 +1279,7 @@ void SubToolWidget::shapeClickedFromWidget(QString shape)
             m_keyBoardButton->click();
         } else if (shape == "mouse") {
             //m_mouseButton->click();
-            if (m_cursorMenu->isHidden()) {
+            if (m_mouseButton->isEnabled() && m_cursorMenu->isHidden()) {
                 m_mouseButton->showMenu();
 //                QPoint point = QWidget::mapToGlobal(m_mouseButton->pos());
 //                m_cursorMenu->move(point.x(),point.y() + m_mouseButton->size().height());
@@ -1257,7 +1290,7 @@ void SubToolWidget::shapeClickedFromWidget(QString shape)
         } else if (shape == "camera") {
             m_cameraButton->click();
         } else if (shape == "audio") {
-            if (m_audioMenu->isHidden()) {
+            if (m_audioButton->isEnabled() && m_audioMenu->isHidden()) {
                 m_audioButton->showMenu();
 //                QPoint point = QWidget::mapToGlobal(m_audioButton->pos());
 //                m_audioMenu->move(point.x(),point.y()+m_audioButton->size().height());
