@@ -22,6 +22,7 @@
 #include "zoomIndicator.h"
 #include "../utils/baseutils.h"
 #include "../utils/tempfile.h"
+#include "../utils.h"
 
 #include <QCursor>
 #include <QTextOption>
@@ -39,6 +40,13 @@ const int BOTTOM_RECT_HEIGHT = 14;
 ZoomIndicator::ZoomIndicator(DWidget *parent)
     : DLabel(parent)
 {
+
+    if (Utils::isWaylandMode) {
+        m_zoomIndicatorGL = new ZoomIndicatorGL(parent);
+        this->hide();
+        return;
+    }
+
     setFixedSize(BACKGROUND_SIZE);
 //    setStyleSheet(getFileContent(":/resources/qss/zoomindicator.qss"));
     setAttribute(Qt::WA_TransparentForMouseEvents);
@@ -52,7 +60,11 @@ ZoomIndicator::ZoomIndicator(DWidget *parent)
     m_globalRect = QRect(0, 0, BACKGROUND_SIZE.width(), BACKGROUND_SIZE.height());
 }
 
-ZoomIndicator::~ZoomIndicator() {}
+ZoomIndicator::~ZoomIndicator() {
+    if (Utils::isWaylandMode && m_zoomIndicatorGL) {
+        delete  m_zoomIndicatorGL;
+    }
+}
 
 
 void ZoomIndicator::paintEvent(QPaintEvent *)
@@ -101,7 +113,21 @@ void ZoomIndicator::paintEvent(QPaintEvent *)
 
 void ZoomIndicator::showMagnifier(QPoint pos)
 {
+    if (Utils::isWaylandMode) {
+        m_zoomIndicatorGL->showMagnifier(pos);
+        return;
+    }
+
     this->show();
 
     this->move(pos);
 }
+
+void ZoomIndicator::hideMagnifier()
+{
+    if (Utils::isWaylandMode) {
+        m_zoomIndicatorGL->hide();
+        return;
+    }
+    this->hide();
+}
