@@ -5,15 +5,18 @@
 
 using namespace testing;
 
-class AudioUtilsTest:public testing::Test{
+class AudioUtilsTest: public testing::Test
+{
 
 public:
     AudioUtils audioUtils ;
-    virtual void SetUp() override{
+    virtual void SetUp() override
+    {
         qDebug() << "start AudioUtilsTest";
     }
 
-    virtual void TearDown() override{
+    virtual void TearDown() override
+    {
         std::cout << "end AudioUtilsTest" << std::endl;
     }
 };
@@ -23,3 +26,10 @@ TEST_F(AudioUtilsTest, currentAudioChannel)
     QString channel = audioUtils.currentAudioChannel();
     //EXPECT_FALSE(channel.isEmpty());
 }
+
+TEST_F(AudioUtilsTest, getDefaultDeviceName)
+{
+    QString sinkName = audioUtils.getDefaultDeviceName(AudioUtils::DefaultAudioType::Sink);
+    QString sourceName = audioUtils.getDefaultDeviceName(AudioUtils::DefaultAudioType::Source);
+    //EXPECT_FALSE(channel.isEmpty());
+}
