@@ -12,6 +12,17 @@ or press the shortcut again to stop recording</source>
         <translation>བརྙན་ལེན་བཞིན་ཡོད་པས་སྐོར་བ་མ་རྒྱག</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>བརྙན་བཤུས།</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ or press the shortcut again to stop recording</source>
         <source>Scrollshot</source>
         <translation>འགུལ་ནས་ཡོལ་པར་བླངས།</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>སྦྱར་རིས།</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ or press the shortcut again to stop recording</source>
         <translation>ཕྱིར་འཐེན།</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>སྦྱར་རིས།</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -333,7 +355,18 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Pin screenshots</source>
-        <translation type="unfinished"/>
+        <translation>སྦྱར་རིས།</translation>
+    </message>
+</context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>བརྙན་བཤུས་བརྙན་ཕབ།</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>བརྙན་བཤུས།</translation>
     </message>
 </context>
 <context>
@@ -510,7 +543,15 @@ or press the shortcut again to stop recording</source>
         <translation>འགུལ་ནས་ཡོལ་པར་བླངས།</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
+        <translation>སྦྱར་རིས།</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ogg</source>
         <translation type="unfinished"/>
     </message>
 </context>
