@@ -14,6 +14,17 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation type="unfinished">Tapadenn-skramm</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -99,6 +110,10 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <source>Scrollshot</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -115,6 +130,13 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <translation>Kuitaat</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -338,6 +360,17 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished">Tapadenn skramm</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation type="unfinished">Tapadenn-skramm</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -512,7 +545,15 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ogg</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
