@@ -12,6 +12,17 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <translation>No gireu la pantalla durant la gravació.</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Captura de pantalla</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <source>Scrollshot</source>
         <translation>Captura de desplaçament</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Fixa les captures</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <translation>Surt</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Fixa les captures</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -336,6 +358,17 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <translation>Fixa les captures</translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Captura de pantalla</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Captura de pantalla</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -510,9 +543,17 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <translation>Captura de desplaçament</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
         <translation>Fixa les captures</translation>
     </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
+    <message>
+        <source>ogg</source>
+        <translation>ogg</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
