@@ -12,6 +12,17 @@ or press the shortcut again to stop recording</translation>
         <translation>Do not rotate your screen during recording</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Screenshot</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation>Recording</translation>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ or press the shortcut again to stop recording</translation>
         <source>Scrollshot</source>
         <translation>Scrollshot</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Pin Screenshots</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ or press the shortcut again to stop recording</translation>
         <translation>Exit</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Pin Screenshots</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -336,6 +358,17 @@ or press the shortcut again to stop recording</translation>
         <translation>Pin screenshots</translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Screen Capture</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Screenshot</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -510,8 +543,16 @@ or press the shortcut again to stop recording</translation>
         <translation>Scrollshot</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
-        <translation>Pin screenshots</translation>
+        <source>Pin Screenshots</source>
+        <translation>Pin Screenshots</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
+    <message>
+        <source>ogg</source>
+        <translation>ogg</translation>
     </message>
 </context>
 <context>
