@@ -12,6 +12,17 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <translation>Scherm niet draaien tijdens opname</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Schermfoto</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <source>Scrollshot</source>
         <translation>Scrollende schermfoto</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Schermfoto&apos;s vastmaken</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <translation>Afsluiten</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Schermfoto&apos;s vastmaken</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -336,6 +358,17 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <translation>Schermfoto&apos;s vastmaken</translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Schermfoto</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Schermfoto</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -510,9 +543,17 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <translation>Scrollende schermfoto</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
         <translation>Schermfoto&apos;s vastmaken</translation>
     </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
+    <message>
+        <source>ogg</source>
+        <translation>ogg</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
