@@ -12,6 +12,17 @@ clique no ícone da bandeja ou use o atalho</translation>
         <translation>Não gire a tela durante a gravação</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Capturar</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ clique no ícone da bandeja ou use o atalho</translation>
         <source>Scrollshot</source>
         <translation>Tela de rolagem</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ clique no ícone da bandeja ou use o atalho</translation>
         <translation>Sair</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -333,7 +355,18 @@ clique no ícone da bandeja ou use o atalho</translation>
     </message>
     <message>
         <source>Pin screenshots</source>
-        <translation type="unfinished"/>
+        <translation>Fixar capturas de tela</translation>
+    </message>
+</context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Captura de Tela</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Capturar</translation>
     </message>
 </context>
 <context>
@@ -510,7 +543,15 @@ clique no ícone da bandeja ou use o atalho</translation>
         <translation>Tela de rolagem</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ogg</source>
         <translation type="unfinished"/>
     </message>
 </context>
