@@ -12,6 +12,17 @@ klikoni ikonën e panelit ose rishtypni shkurtoren</translation>
         <translation>Mos e rrotulloni ekranin tuaj gjatë regjistrimit</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Foto ekrani</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ klikoni ikonën e panelit ose rishtypni shkurtoren</translation>
         <source>Scrollshot</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ klikoni ikonën e panelit ose rishtypni shkurtoren</translation>
         <translation>Dil</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -336,6 +358,17 @@ klikoni ikonën e panelit ose rishtypni shkurtoren</translation>
         <translation>Fiksoje foton e ekranit</translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Regjistrim Ekrani</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Foto ekrani</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -510,8 +543,16 @@ klikoni ikonën e panelit ose rishtypni shkurtoren</translation>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Pin screenshots</source>
-        <translation>Fiksoje foton e ekranit</translation>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ogg</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
