@@ -12,6 +12,17 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
         <translation>Kayıt boyunca ekranınızı döndürmeyin</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Ekran Görüntüsü</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
         <source>Scrollshot</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
         <translation>Çıkış</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -155,7 +177,7 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
     </message>
     <message>
         <source>Reached the maximum length</source>
-        <translation>Maksimum uzunluğa ulaştı</translation>
+        <translation>Azami uzunluğa ulaştı</translation>
     </message>
     <message>
         <source>adjust the capture area</source>
@@ -333,7 +355,18 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
     </message>
     <message>
         <source>Pin screenshots</source>
-        <translation type="unfinished"/>
+        <translation>Ekran görüntülerini sabitle</translation>
+    </message>
+</context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Ekran Alıntısı</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Ekran Görüntüsü</translation>
     </message>
 </context>
 <context>
@@ -510,7 +543,15 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ogg</source>
         <translation type="unfinished"/>
     </message>
 </context>
